@@ -20,7 +20,7 @@ checkScalar = function(x, na.ok = FALSE) {
 #' @include makeAssertion.r
 #' @template assert
 #' @rdname checkScalar
-assertScalar = makeAssertionFunction(checkScalar)
+assertScalar = makeAssertionFunction(checkScalar, c.fun = "c_check_scalar")
 
 #' @export
 #' @rdname checkScalar
@@ -29,7 +29,7 @@ assert_scalar = assertScalar
 #' @export
 #' @include makeTest.r
 #' @rdname checkScalar
-testScalar = makeTestFunction(checkScalar)
+testScalar = makeTestFunction(checkScalar, c.fun = "c_check_scalar")
 
 #' @export
 #' @rdname checkScalar
@@ -39,4 +39,4 @@ test_scalar = testScalar
 #' @include makeExpectation.r
 #' @template expect
 #' @rdname checkScalar
-expect_scalar = makeExpectationFunction(checkScalar)
+expect_scalar = makeExpectationFunction(checkScalar, c.fun = "c_check_scalar")
