@@ -1,12 +1,8 @@
-#' The checkmate package
-#'
-#' @name checkmate
-#' @docType package
-#' @section Additional information:
+#' @details
 #'
 #' \describe{
 #'   \item{Homepage:}{\url{https://github.com/mllg/checkmate}}
 #' }
 #' @importFrom utils head
 #' @importFrom utils tail
-NULL
+"_PACKAGE"
