@@ -58,7 +58,7 @@ R_len_t get_ncols(SEXP x) {
 
 
 double asNumber(SEXP x, const char *vname) {
-    if (!isNumeric(x) || length(x) != 1)
+    if (!isNumeric(x) || xlength(x) != 1)
         error("Argument '%s' must be a number", vname);
     double xd = asReal(x);
     if (ISNAN(xd))
@@ -67,15 +67,15 @@ double asNumber(SEXP x, const char *vname) {
 }
 
 const char * asString(SEXP x, const char *vname) {
-    if (!isString(x) || length(x) != 1)
+    if (!isString(x) || xlength(x) != 1)
         error("Argument '%s' must be a string", vname);
     if (any_missing_string(x))
         error("Argument '%s' may not be missing", vname);
     return CHAR(STRING_ELT(x, 0));
 }
 
-R_len_t asCount(SEXP x, const char *vname) {
-    if (!isIntegerish(x, INTEGERISH_DEFAULT_TOL) || length(x) != 1)
+R_xlen_t asCount(SEXP x, const char *vname) {
+    if (!isIntegerish(x, INTEGERISH_DEFAULT_TOL) || xlength(x) != 1)
         error("Argument '%s' must be a count", vname);
     int xi = asInteger(x);
     if (xi == NA_INTEGER)
@@ -86,7 +86,7 @@ R_len_t asCount(SEXP x, const char *vname) {
 }
 
 Rboolean asFlag(SEXP x, const char *vname) {
-    if (!isLogical(x) || length(x) != 1)
+    if (!isLogical(x) || xlength(x) != 1)
         error("Argument '%s' must be a flag", vname);
     Rboolean xb = LOGICAL(x)[0];
     if (xb == NA_LOGICAL)
