@@ -2,9 +2,9 @@ context("checkInt")
 
 test_that("checkInt", {
   myobj = 1L
-  expect_succ(Int, myobj)
+  expect_succ_all(Int, myobj)
   myobj = 1.1
-  expect_fail(Int, myobj)
+  expect_fail_all(Int, myobj)
 
   expect_false(testInt(integer(0)))
   expect_false(testInt(NULL))
@@ -18,3 +18,11 @@ test_that("checkInt", {
 
   expect_error(assertInt(2+3i), "integerish")
 })
+
+
+test_that("bounds of vectors with only missings are not checked", {
+  expect_true(checkInt(NA, na.ok = TRUE, lower = 1))
+  expect_true(checkInt(NA_character_, na.ok = TRUE, upper = 10))
+  expect_fail_all(Int, 0L, lower = 1L)
+  expect_fail_all(Int, 100L, upper = 10L)
+})
